@@ -1,7 +1,9 @@
 package com.unciv.ui.components
 
-import com.badlogic.gdx.Gdx
 import com.badlogic.gdx.Input
+import com.badlogic.gdx.utils.Json
+import com.badlogic.gdx.utils.JsonValue
+
 
 /*
  * For now, many combination keys cannot easily be expressed.
@@ -44,9 +46,6 @@ data class KeyCharAndCode(val char: Char, val code: Int) {
     }
 
     companion object {
-        /** Tests presence of a physical keyboard - static here as convenience shortcut only */
-        val keyboardAvailable = Gdx.input.isPeripheralAvailable(Input.Peripheral.HardwareKeyboard)
-
         // Convenience shortcuts for frequently used constants
         /** Android back, assigns ESC automatically as well */
         val BACK = KeyCharAndCode(Input.Keys.BACK)
@@ -83,74 +82,32 @@ data class KeyCharAndCode(val char: Char, val code: Int) {
             val code = Input.Keys.valueOf(char.uppercaseChar().toString())
             return if (code == -1) KeyCharAndCode(char,0) else KeyCharAndCode(Char.MIN_VALUE, code)
         }
-    }
-}
 
-
-data class KeyShortcut(val key: KeyCharAndCode, val priority: Int = 0)
-
-
-open class KeyShortcutDispatcher {
-    private val shortcuts: MutableList<Pair<KeyShortcut, () -> Unit>> = mutableListOf()
-
-    fun add(shortcut: KeyShortcut?, action: (() -> Unit)?): Unit {
-        if (action == null || shortcut == null) return
-        shortcuts.removeIf { it.first == shortcut }
-        shortcuts.add(Pair(shortcut, action))
-    }
-
-    fun add(key: KeyCharAndCode?, action: (() -> Unit)?): Unit {
-        if (key != null)
-            add(KeyShortcut(key), action)
-    }
-
-    fun add(char: Char?, action: (() -> Unit)?): Unit {
-        if (char != null)
-            add(KeyCharAndCode(char), action)
-    }
-
-    fun add(keyCode: Int?, action: (() -> Unit)?): Unit {
-        if (keyCode != null)
-            add(KeyCharAndCode(keyCode), action)
-    }
-
-    fun remove(shortcut: KeyShortcut?): Unit {
-        shortcuts.removeIf { it.first == shortcut }
-    }
-
-    fun remove(key: KeyCharAndCode?): Unit {
-        shortcuts.removeIf { it.first.key == key }
-    }
-
-    fun remove(char: Char?): Unit {
-        shortcuts.removeIf { it.first.key.char == char }
-    }
-
-    fun remove(keyCode: Int?): Unit {
-        shortcuts.removeIf { it.first.key.code == keyCode }
-    }
-
-    open fun isActive(): Boolean = true
-
-
-    class Resolver(val key: KeyCharAndCode) {
-        private var priority = Int.MIN_VALUE
-        val trigerredActions: MutableList<() -> Unit> = mutableListOf()
-
-        fun updateFor(dispatcher: KeyShortcutDispatcher) {
-            if (!dispatcher.isActive()) return
-
-            for (shortcut in dispatcher.shortcuts) {
-                if (shortcut.first.key == key) {
-                    if (shortcut.first.priority == priority)
-                        trigerredActions.add(shortcut.second)
-                    else if (shortcut.first.priority > priority) {
-                        priority = shortcut.first.priority
-                        trigerredActions.clear()
-                        trigerredActions.add(shortcut.second)
-                    }
-                }
+        fun parse(text: String): KeyCharAndCode = when {
+                text.length == 1 && text[0].isDefined() -> KeyCharAndCode(text[0])
+                text.length == 3 && text[0] == '"' && text[2] == '"' -> KeyCharAndCode(text[1])
+                text.length == 6 && text.startsWith("Ctrl-") -> ctrl(text[5])
+                text == "ESC" -> ESC
+                text == "Backspace" -> KeyCharAndCode(Input.Keys.BACKSPACE)
+                text == "Del" -> DEL
+                Input.Keys.valueOf(text) != -1 -> KeyCharAndCode(Input.Keys.valueOf(text))
+                else -> UNKNOWN
             }
+    }
+
+    class Serializer : Json.Serializer<KeyCharAndCode> {
+        override fun write(json: Json, key: KeyCharAndCode, knownType: Class<*>?) {
+            // Gdx Json is.... No comment. This `Any` is needed to resolve the ambiguity between
+            //      public void writeValue (String name, @Null Object value, @Null Class knownType)
+            // and
+            //      public void writeValue (@Null Object value, @Null Class knownType, @Null Class elementType)
+            // - we want the latter. And without the explicitly provided knownType it will _unpredictably_ use
+            // `{"class":"java.lang.String","value":"Space"}` instead of `"Space"`.
+            json.writeValue(key.toString() as Any, String::class.java, null)
+        }
+
+        override fun read(json: Json, jsonData: JsonValue, type: Class<*>?): KeyCharAndCode {
+            return parse(jsonData.asString())
         }
     }
 }
